@@ -288,6 +288,7 @@ class Cursor(common.DBAPICursor):
         return
 
     def rowcount(self):
+        _logger.info("fetch returning the rowcount from e6x itself")
         return self._rowcount
 
     def cancel(self):
@@ -363,12 +364,14 @@ class Cursor(common.DBAPICursor):
         #     row = None
         #     # reset row counter for next query execution
         #     self.rows_count = 0
-
+        records = []
         row = self._batch.pop()
         for i in row:
             self.rows_count += 1
             if self.rows_count <= 1000:
-                return row
+                records.append(i)
+                # return row
+                return records
             else:
                 return None
 
@@ -397,11 +400,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="44.203.152.210",
+    connection = connect(host="44.201.53.50",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="tpc_330mb",
+                         database="perf_hive_100gb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -415,14 +418,15 @@ if __name__ == '__main__':
     try:
         while len(bdata) > 0:
             print(bdata)
-            print(len(bdata))
+            print('total columns in the resultset ', len(bdata))
             bdata = cursor.fetchone()
+            r_count = cursor.rowcount()
+            print('total row count', r_count)
             # list(islice(iter(bdata, None), 10000))
     except Exception as e:
+        print('Error Message ', e.__cause__)
         cursor.close()
 
-    cursor.clear()
-
 #
 # Type Objects and Constructors
 #
